#!/usr/bin/env python
import os
import subprocess
import sys


def main():
    managepy_path = find_managepy()
    if managepy_path:
        command = ' '.join(['python', managepy_path] + sys.argv[1:])
        run_cmd(command)
    else:
        print("Couldn't find manage.py")


def find_managepy():
    # We start in current directory
    path = '.'
    # We will stop at the root directory
    while os.path.split(os.path.abspath(path))[1]:
        check_path = os.path.join(path, 'manage.py')
        if os.path.exists(check_path):
            return os.path.abspath(check_path)
        # Go level up
        path = os.path.join('..', path)


def run_cmd(command):
    try:
        subprocess.call(command, shell=True)
    except KeyboardInterrupt:
        print("Command aborted")


main()



from distutils.core import setup

setup(
    name='django_managepy_anywhere',
    version='2.0',
    description='Allows to run manage.py commands from any level of the Django project by typing "manage.py <subcommand>"',
    author='Tim Kamanin',
    author_email='tim@timonweb.com',
    url='https://timonweb.com/oss/django-managepy-anywhere/',
    download_url='https://github.com/timonweb/Django-manage.py-anywhere/archive/master.zip',
    keywords=['django', 'management', 'commands'],
    scripts=['bin/manage.py'],
)
